#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import find_packages
from setuptools import setup


extras_require = {
    'dev': [
        'pytest',
        'mocker',
        'pytest-mock',
        'pylint',
    ],
    'config': [
        'argcomplete',
        'keyring',
        'systemd-python',
    ],
    'ldap': [
        'python-ldap',
        'python-dateutil',
        'pytz',
    ],
    'email': [
        'mako',
    ],
    'pgsql': [
        'psycopg2',
    ],
    'oracle': [
        'cx_Oracle',
    ],
    'mysql': [
        'mysqlclient',
    ],
    'sftp': [
        'paramiko',
    ],
}

install_requires = ['progressbar']
for extra, deps in extras_require.items():
    if extra != 'dev':
        install_requires.extend(deps)

version = '0.1'

setup(
    name="mylib",
    version=version,
    description='A set of helpers small libs to make common tasks easier in my script development',
    classifiers=[
        'Programming Language :: Python',
    ],
    install_requires=install_requires,
    extras_require=extras_require,
    author='Benjamin Renard',
    author_email='brenard@zionetrix.net',
    url='https://gogs.zionetrix.net/bn8/python-mylib',
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    entry_points={
        'console_scripts': [
            'mylib-test-email = mylib.scripts.email_test:main',
            'mylib-test-email-with-config = mylib.scripts.email_test_with_config:main',
            'mylib-test-pbar = mylib.scripts.pbar_test:main',
            'mylib-test-report = mylib.scripts.report_test:main',
            'mylib-test-ldap = mylib.scripts.ldap_test:main',
            'mylib-test-sftp = mylib.scripts.sftp_test:main',
        ],
    },
)
